# Generated by Django 2.2.16 on 2020-10-29 16:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("django_video_encoder", "0003_auto_20201029_1613"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="format",
            name="format",
        ),
    ]
