# Generated by Django 2.2.16 on 2020-10-29 16:13

from django.db import migrations, models
from django.db.models import F


def update_formats(apps, schema_editor):
    Format = apps.get_model("django_video_encoder", "Format")
    Format.objects.update(format_label=F("format"))


class Migration(migrations.Migration):

    dependencies = [
        ("django_video_encoder", "0002_auto_20201022_1647"),
    ]

    operations = [
        migrations.AddField(
            model_name="format",
            name="format_label",
            field=models.CharField(default="", editable=False, max_length=80),
        ),
        migrations.AddField(
            model_name="format",
            name="video_codec",
            field=models.CharField(
                choices=[
                    ("h264", "h264"),
                    ("hevc", "hevc"),
                    ("jp2", "jp2"),
                    ("mpeg4", "mpeg4"),
                    ("theora", "theora"),
                    ("vp6", "vp6"),
                    ("vp8", "vp8"),
                    ("vp9", "vp9"),
                    ("wmv", "wmv"),
                ],
                default="h264",
                max_length=50,
            ),
        ),
        migrations.RunPython(update_formats, reverse_code=migrations.RunPython.noop),
    ]
